@@ -208,6 +208,7 @@ class MainController(QMainWindow):
             self.on_show_field_types_config_action_triggered)
 
         self.compare_frame_controller.load_protocol_clicked.connect(self.on_compare_frame_controller_load_protocol_clicked)
+        self.compare_frame_controller.ui.listViewParticipants.doubleClicked.connect(self.on_project_settings_action_triggered)
 
         self.ui.lnEdtTreeFilter.textChanged.connect(self.on_file_tree_filter_text_changed)
 
@@ -257,6 +258,7 @@ class MainController(QMainWindow):
         proto = self.compare_frame_controller.add_protocol_from_file(filename)
         if proto:
             self.__add_empty_frame_for_filename(proto, filename)
+        self.ui.tabWidget.setCurrentWidget(self.ui.tab_protocol)
 
     def add_fuzz_profile(self, filename):
         self.ui.tabWidget.setCurrentIndex(2)
@@ -350,7 +352,7 @@ class MainController(QMainWindow):
             self.set_frame_numbers()
             self.refresh_main_menu()
         except Exception as e:
-            Errors.generic_error(self.tr("Failed to close"), str(e), traceback.format_exc())
+            Errors.exception(e)
             self.unsetCursor()
 
     def add_files(self, filepaths, group_id=0, enforce_sample_rate=None):
@@ -558,7 +560,7 @@ class MainController(QMainWindow):
                 self.add_files(FileOperator.uncompress_archives([action.data()], QDir.tempPath()))
                 self.unsetCursor()
         except Exception as e:
-            Errors.generic_error(self.tr("Failed to open"), str(e), traceback.format_exc())
+            Errors.exception(e)
             self.unsetCursor()
 
     @pyqtSlot()
@@ -656,6 +658,9 @@ class MainController(QMainWindow):
                 self.generator_tab_controller.ui.tabWidget.widget(i).layout().setContentsMargins(0, 7 + h - th, 0, 0)
             # Modulators may got changed from Simulator Dialog
             self.generator_tab_controller.refresh_modulators()
+            # Signals may got reordered in analysis
+            self.generator_tab_controller.tree_model.update()
+            self.generator_tab_controller.ui.treeProtocols.expandAll()
 
     @pyqtSlot()
     def on_show_record_dialog_action_triggered(self):
@@ -778,7 +783,7 @@ class MainController(QMainWindow):
                     self.add_files(file_names)
                     self.unsetCursor()
             except Exception as e:
-                Errors.generic_error(self.tr("Failed to open"), str(e), traceback.format_exc())
+                Errors.exception(e)
                 self.unsetCursor()
 
     @pyqtSlot()
